aboutsummaryrefslogtreecommitdiff
path: root/grs
diff options
context:
space:
mode:
authorAnthony G. Basile <blueness@gentoo.org>2018-01-10 16:01:55 -0500
committerAnthony G. Basile <blueness@gentoo.org>2018-01-10 16:01:55 -0500
commit7fdb50bd3be0467d2bfefac8fde9554ed7956cce (patch)
treec777426c5fcb8ba976ef5145859f412dd5fddf26 /grs
parentgrs/Netboot.py: use busybox built by genkernel (diff)
downloadgrss-7fdb50bd3be0467d2bfefac8fde9554ed7956cce.tar.gz
grss-7fdb50bd3be0467d2bfefac8fde9554ed7956cce.tar.bz2
grss-7fdb50bd3be0467d2bfefac8fde9554ed7956cce.zip
grs/Netboot.py: switch from xz to gzip compression
Diffstat (limited to 'grs')
-rw-r--r--grs/Netboot.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/grs/Netboot.py b/grs/Netboot.py
index 985bcfd..307b3b3 100644
--- a/grs/Netboot.py
+++ b/grs/Netboot.py
@@ -65,9 +65,9 @@ class Netboot(HashIt):
shutil.rmtree(initramfs_root, ignore_errors=True)
os.makedirs(initramfs_root, mode=0o755, exist_ok=False)
# We will only use xz compression
initramfs_src = os.path.join(self.portage_configroot, 'boot/initramfs')
- cmd = 'xz -dc %s | cpio -idv' % (initramfs_src)
+ cmd = 'cat %s | gunzip | cpio -idv' % (initramfs_src)
cwd = os.getcwd()
os.chdir(initramfs_root)
@@ -95,7 +95,7 @@ class Netboot(HashIt):
shutil.rmtree(squashfs_dir, ignore_errors=True)
os.makedirs(squashfs_dir, mode=0o755, exist_ok=False)
squashfs_path = os.path.join(squashfs_dir, 'image.squashfs')
- cmd = 'mksquashfs %s %s -xattrs -comp xz' % (self.portage_configroot, squashfs_path)
+ cmd = 'mksquashfs %s %s -xattrs -comp gzip' % (self.portage_configroot, squashfs_path)
Execute(cmd, timeout=None, logfile=self.logfile)
# 4. Copy in the init script
@@ -106,7 +106,7 @@ class Netboot(HashIt):
# 5. Repack
initramfs_dst = os.path.join(self.tmpdir, self.medium_name)
- cmd = 'find . -print | cpio -H newc -o | xz -9e --check=none -z -f > %s' % initramfs_dst
+ cmd = 'find . -print | cpio -H newc -o | gzip -9 -f > %s' % initramfs_dst
cwd = os.getcwd()
os.chdir(initramfs_root)
@@ -65,9 +65,9 @@ class Netboot(HashIt):
shutil.rmtree(initramfs_root, ignore_errors=True)
os.makedirs(initramfs_root, mode=0o755, exist_ok=False)
- # We will only use xz compression
+ # We will use gzip compression
initramfs_src = os.path.join(self.portage_configroot, 'boot/initramfs')